Nengolib is an open-source library of routines created in an effort to exploit
Nengo's full potential. It was started by Aaron Voelker from the University of
Waterloo as a collection of tools made available through work on his PhD
dissertation.

We acknowledge the following people and institutions for their support
during the development of this code (in alphabetical order):

People
""""""

* Chris Eliasmith for his supervision, guidance, feedback, and testing.
* Eric Hunsberger for his guidance in the areas of signal processing and linear
  systems theory.
* Michael Hopkins for providing background information on number-theoretic
  methods for obtaining more scattered samples.
* Terrence C. Stewart for helping develop the ideas behind reservoir computing
  in Nengo by solving for the decoders over time.

Institutions
""""""""""""

* Applied Brain Research (ABR), Inc., for this library could not exist
  in any meaningful state without Nengo.
* The Centre for Theoretical Neuroscience and the University of Waterloo for
  their academic support during the development of this library.
